
# Slot: term

The ontology term that describes the nature of the association

URI: [gocam:termAssociation__term](https://w3id.org/gocam/termAssociation__term)


## Domain and Range

None &#8594;  <sub>0..1</sub> [TermObject](TermObject.md)

## Parents


## Children

 *  [BiologicalProcessAssociation➞term](BiologicalProcessAssociation_term.md)
 *  [CellTypeAssociation➞term](CellTypeAssociation_term.md)
 *  [CellularAnatomicalEntityAssociation➞term](CellularAnatomicalEntityAssociation_term.md)
 *  [GrossAnatomyAssociation➞term](GrossAnatomyAssociation_term.md)
 *  [MolecularFunctionAssociation➞term](MolecularFunctionAssociation_term.md)
 *  [MoleculeAssociation➞term](MoleculeAssociation_term.md)

## Used by

 * [TermAssociation](TermAssociation.md)
